#!/bin/bash
# packager           : Markus Muttilainen <stillborn>
# source location    : http://www.abisource.com/
# last revised       : 10.05.2011

set -x -e -u

softname='abiword'
softversion='2.8.6'
packageversion='70.2'

arch='i486'
cpu='i686'

INS644="install -o root -g root -m 644"
INS755="install -d -o root -g root -m 755"

prefix=/usr

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.abisource.com/downloads/abiword/$softversion/source/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
$INS755 $dest
$INS755 $dest/install
$INS755 $dest/usr/doc/$softname-$softversion
$INS755 $dest/usr/share/icons/hicolor/48x48/apps
$INS755 $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
abiword: abiword (word processor) 
abiword:
abiword: AbiWord Personal is a lean and fast full-featured word processor.  It
abiword: can import many formats including Word97/2000 and RTF, Palm, Psion, 
abiword: DocBook and XHTML documents, and can export to RTF, Palm, Psion, 
abiword: XHTML, Text, and LaTeX formats.  Linux Journal calls it "an elegant, 
abiword: open source word processor that delivers the Word functionality most
abiword: people use." This version is built against gnome-libs.
abiword:
abiword:
abiword:
EOF

# check if package is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar zxvf $srcpkg

# build
cd $src

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --mandir=/usr/man \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux || exit

    make
    make install DESTDIR=$dest

# add 'default' files
    $INS644 \
       AUTHORS BUILD.TXT COPYING COPYRIGHT.TXT ChangeLog INSTALL NEWS README \
       $dest/usr/doc/$softname-$softversion
      
# Compress Man Pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# Strip
( cd $dest
  find . | xargs file | grep -e "executable" -e "shared object" | grep ELF | cut -s -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
)

# .desktop file "user"
sed -i -e "s|Icon=abiword_48|Icon=abiword|g" $dest/usr/share/applications/abiword.desktop

# Make the package freedesktop compliant
mv $dest/usr/share/icons/abiword_48.png $dest/usr/share/icons/hicolor/48x48/apps/abiword.png
cd $dest/usr/share/icons/
ln -s hicolor/48x48/apps/abiword.png abiword_48.png

# ZenBuild
$INS644 $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# .dep
#cd $buildir
#echo -e "atk,bzip2,cairo,cxxlibs|gcc-g++,enchant,expat,fontconfig,freetype,fribidi,gcc,glib2,gtk+2,\
#libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,libXfixes,libXi,libXinerama,\
#libXrandr,libXrender,libgsf,libjpeg,libpng,librsvg,libxcb,libxml2,pango,pixman,wv,zlib" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/stillborn/abiword/build-abiword.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
